/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: CtxClassLoaderObjectInputStream.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.marshalling;


import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;

/**
 * Reader which use the context classloader when recreating the object.
 * @author Florent Benoit
 */
public class CtxClassLoaderObjectInputStream extends ClassLoaderObjectInputStream {

    /**
     * This inputstream reader needs an input stream for its constructor.
     * @param inputStream input stream containing bytes
     * @throws IOException if super class fails
     */
    public CtxClassLoaderObjectInputStream(final InputStream inputStream) throws IOException {
        super(inputStream, Thread.currentThread().getContextClassLoader());
    }

    /**
     * This inputstream reader needs an input stream for its constructor.
     * @param inputStream input stream containing bytes
     * @throws IOException if super class fails
     */
    public CtxClassLoaderObjectInputStream(final ObjectInputStream inputStream) throws IOException {
        super(inputStream, Thread.currentThread().getContextClassLoader());
    }


}
